@@ -11,7 +11,7 @@
 class EClinicalUser:
 
     def __init__(self, username=None, password=None, sponsor=None, study=None, test_env=None, app_env=None, app=None,
-                 company=None, role=None, external=False, org_code=None):
+                 company=None, role=None, external=False, org_code=None, token=None):
         # username 用户名
         # password 密码
         # app 访问的系统
@@ -30,6 +30,7 @@ class EClinicalUser:
         self.external = external
         self.company_level_login = False
         self.org_code = org_code
+        self.token = token  # 使用token直接调用接口
 
     def __repr__(self):
         attributes = self.__dict__
